;+
; NAME: eis_hk1_temperatures.pro
;
; PURPOSE: To convert status hk1 parameters from telemetered values
;          to engineering values
;      
; CATEGORY:
;
; CALLING SEQUENCE: 
;
; INPUTS: 
;
; KEYWORD PARAMETERS: None
;
; OUTPUTS: 
;
; CALLS:
;
; COMMON BLOCKS: None
;
; PROCEDURE:
;
; RESTRICTIONS: Uses SolarSoft
;
; MODIFICATION HISTORY:
;	03/June/2006 v1.0 mcrw wrote
;       15/Nov/2006  v1.1 mcrw minor corrections
;
;-------------------------------------------------------------------------------------------------

pro eis_status_hk1_data_dumper::check_icu_temps, lu
  self->trace, 'eis_status_hk1_data_dumper::check_icu_temps'
  
  print, '	icu_temps'
  
  title_str = 'ICU temperatures (C)            min            max                avg'

  self->retrieve, 'icu_temps', 'HK1_EIS_ICU_1_TEMP', mn0, mx0, avg0
  self->retrieve, 'icu_temps', 'HK1_EIS_ICU_2_TEMP', mn1, mx1, avg1

  p0_str = 'Icu-1                 ' + eis_num2str(mn0, type='degC') + eis_num2str(mx0, type='degC') + eis_num2Str(avg0, type='degC')
  p1_str = 'Icu-2                 ' + eis_num2str(mn1, type='degC') + eis_num2str(mx1, type='degC') + eis_num2Str(avg1, type='degC')

  printf, lu, title_str
  printf, lu, p0_str
  printf, lu, p1_str
  printf, lu


end

pro eis_status_hk1_data_dumper::check_sur_temps, lu
  self->trace, 'eis_status_hk1_data_dumper::check_sur_temps'
  
  print, '	sur_temps'

  title_str = 'HTR temperatures (C)            min            max                avg'

  self->retrieve, 'sur_temps', 'HK1_EIS_A_HTR_TMP', mn0, mx0, avg0
  self->retrieve, 'sur_temps', 'HK1_EIS_B_HTR_TMP', mn1, mx1, avg1
  self->retrieve, 'sur_temps', 'HK1_EIS_C_HTR_TMP', mn2, mx2, avg2

  p0_str = 'Htr-A                 ' + eis_num2str(mn0, type='degC') + eis_num2str(mx0, type='degC') + eis_num2Str(avg0, type='degC')
  p1_str = 'Htr-B                 ' + eis_num2str(mn1, type='degC') + eis_num2str(mx1, type='degC') + eis_num2Str(avg1, type='degC')
  p2_str = 'Htr-C                 ' + eis_num2str(mn2, type='degC') + eis_num2str(mx2, type='degC') + eis_num2Str(avg2, type='degC')

  printf, lu, title_str
  printf, lu, p0_str
  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu

end

pro eis_status_hk1_data_dumper::check_str_temps, lu
  self->trace, 'eis_status_hk1_data_dumper::check_str_temps'
  
  print, '	str_temps'

  title_str = 'STR temperatures (C)            min            max                avg'

  self->retrieve, 'str_temps', 'HK1_EIS_STR_1_TEMP', mn0, mx0, avg0
  self->retrieve, 'str_temps', 'HK1_EIS_STR_2_TEMP', mn1, mx1, avg1
  self->retrieve, 'str_temps', 'HK1_EIS_STR_3_TEMP', mn2, mx2, avg2
  self->retrieve, 'str_temps', 'HK1_EIS_STR_4_TEMP', mn3, mx3, avg3
  self->retrieve, 'str_temps', 'HK1_EIS_STR_5_TEMP', mn4, mx4, avg4
  self->retrieve, 'str_temps', 'HK1_EIS_STR_6_TEMP', mn5, mx5, avg5
  self->retrieve, 'str_temps', 'HK1_EIS_STR_7_TEMP', mn6, mx6, avg6
    
  p0_str = 'Str-1                 ' + eis_num2str(mn0, type='degC') + eis_num2str(mx0, type='degC') + eis_num2Str(avg0, type='degC')
  p1_str = 'Str-2                 ' + eis_num2str(mn1, type='degC') + eis_num2str(mx1, type='degC') + eis_num2Str(avg1, type='degC')
  p2_str = 'Str-3                 ' + eis_num2str(mn2, type='degC') + eis_num2str(mx2, type='degC') + eis_num2Str(avg2, type='degC')
  p3_str = 'Str-4                 ' + eis_num2str(mn3, type='degC') + eis_num2str(mx3, type='degC') + eis_num2Str(avg3, type='degC')
  p4_str = 'Str-5                 ' + eis_num2str(mn4, type='degC') + eis_num2str(mx4, type='degC') + eis_num2Str(avg4, type='degC')
  p5_str = 'Str-6                 ' + eis_num2str(mn5, type='degC') + eis_num2str(mx5, type='degC') + eis_num2Str(avg5, type='degC')
  p6_str = 'Str-7                 ' + eis_num2str(mn6, type='degC') + eis_num2str(mx6, type='degC') + eis_num2Str(avg6, type='degC')

  printf, lu, title_str
  printf, lu, p0_str
  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu, p6_str
  printf, lu
end


pro eis_status_hk1_data_dumper::check, lu
  self->trace, 'eis_status_hk1_data_dumper::check'
  
  print, 'eis_status_hk1_data_dumper::check'
  
  self->check_icu_temps, lu
  self->check_sur_temps, lu
  self->check_str_temps, lu
  
 end
