;+
; NAME: eis_hk1_temperatures.pro
;
; PURPOSE: To convert status hk1 parameters from telemetered values
;          to engineering values
;      
; CATEGORY:
;
; CALLING SEQUENCE: 
;
; INPUTS: 
;
; KEYWORD PARAMETERS: None
;
; OUTPUTS: 
;
; CALLS:
;
; COMMON BLOCKS: None
;
; PROCEDURE:
;
; RESTRICTIONS: Uses SolarSoft
;
; MODIFICATION HISTORY:
;	03/June/2006 v1.0 mcrw wrote
;       15/Nov/2006  v1.1 mcrw minor corrections
;
;-------------------------------------------------------------------------------------------------

pro eis_status_hk1_data_dumper::plot_icu_temps, files, output, end_time
  self->trace, 'eis_status_hk1_data_dumper::plot_icu_temps'
  
;  print, '	icu_temps'
  
;  icu_1 = eis_convert_hk1_icu1_temp(eis_get_daily_data(files, 'HK1_EIS_ICU_1_TEMP', 4, 1, mx0, mn0, base_time, end_time))
  d = eis_get_daily_data(files, 'HK1_EIS_ICU_1_TEMP', 4, 1, mx0, mn0, base_time, end_time)
  icu_1 = eis_convert_hk1_icu1_temp(d)
  print, 'ICU1'
  print, d[0:3], format = '(Z02)'    
;  icu_2 = eis_convert_hk1_icu2_temp(eis_get_daily_data(files, 'HK1_EIS_ICU_2_TEMP', 5, 1, mx1, mn1))
  d = eis_get_daily_data(files, 'HK1_EIS_ICU_2_TEMP', 5, 1, mx1, mn1)
  icu_2 = eis_convert_hk1_icu2_temp(d)
  print, 'ICU2'
  print, d[0:3], format = '(Z02)'  

  avg = (nan_moment(icu_1))[0]
  mn = min(icu_1)
  mx = max(icu_1)
  self->record, 'icu_temps', 'HK1_EIS_ICU_1_TEMP', mn, mx, avg
  avg = (nan_moment(icu_2))[0]
  mn = min(icu_2)
  mx = max(icu_2)
  self->record, 'icu_temps', 'HK1_EIS_ICU_2_TEMP', mn, mx, avg
  
  x = lindgen(n_elements(icu_1)) * 2
  
; Need to convert the min and max before doing this step
  minr = min([eis_convert_hk1_icu1_temp([mn0]), eis_convert_hk1_icu2_temp([mn1])])
  maxr = max([eis_convert_hk1_icu1_temp([mx0]), eis_convert_hk1_icu2_temp([mx1])])

;  do_plot, 'eis_icu_temps.ps', [icu_1, icu_2], 2, [base_time, end_time], [minr - 1, maxr + 1], ['ICU 1 Base Plate', 'ICU 2 Top Plate'], 'Temp. (Deg C)'

  cs = 1.6
  
;    window, /free, xsize=1024
;    !p.multi=0
;    utplot, x, htr_a_array, base_time, timerange=[base_time,end_time],yrange=[minr-1,maxr+1],xstyle=2,pstyle=4,title='Htr A', ytitl='Temp. (Deg C)',charsize=cs
;    outplot,x, htr_b_array,color='0000FF'x
;    outplot,x, htr_c_array,color='00FFFF'x

  set_plot,'ps'
                                ; Could use encapsulated here
;;;    device,xoff=2.5,yoff=6,xs=16,ys=18,file='/tmp/eis_icu_temps.ps'
  device, xoff = 2.5, yoff = 6, xs = 16, ys = 18, file = output + '/eis_icu_temps.ps', /portrait
  !p.multi = [0, 1, 3]
  utplot, x, icu_1, base_time, timerange = [base_time, end_time], yrange = [minr - 1, maxr + 1], xstyle = 2, pstyle = 4, $
          title = 'ICU 1 Base Plate', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, icu_2, base_time, timerange = [base_time, end_time], yrange = [minr - 1, maxr + 1], xstyle = 2, pstyle = 4, $
          title = 'ICU 2 Top Plate', ytitle = 'Temp. (Deg C)', charsize = cs
  device, /close
  set_plot, 'X'
end

;pro do_plot, outf, params, multiplier, timrange, minmax, titles, unit_str
;  x = lindgen(n_elements(params[0])) * multiplier
;  cs = 1.6
;  set_plot, 'ps'
;  device, xoff = 2.5, yoff = 6, xs = 16, ys = 18, file = output + '/' + outf, /portrait
;  !p.multi = [0, 1, 3]
;  for d, n_elements(params) do begin
;     utplot, x, params[d], timrange[0], timerange = timrange, yrange = minmax, xstyle = 2, pstyle = 4, $
;             title = titles[d], ytitle = unit_str, charsize = cs
;  endfor
;  device, /close
;  set_plot, 'X'
;end

pro eis_status_hk1_data_dumper::plot_sur_temps, files, output, end_time
  self->trace, 'eis_status_hk1_data_dumper::plot_sur_temps'
  
;  print, '	sur_temps'
  
;  htr_a = eis_convert_hk1_htra_temp(eis_get_daily_data(files, 'HK1_EIS_A_HTR_TMP', 1, 1, mx0, mn0, base_time, end_time))
  d = eis_get_daily_data(files, 'HK1_EIS_A_HTR_TMP', 1, 1, mx0, mn0, base_time, end_time)
  htr_a = eis_convert_hk1_htra_temp(d)
  print, 'HTRA'
  print, d[0:3], format = '(Z02)'
;  htr_b = eis_convert_hk1_htrb_temp(eis_get_daily_data(files, 'HK1_EIS_B_HTR_TMP', 2, 1, mx1, mn1))
  d = eis_get_daily_data(files, 'HK1_EIS_B_HTR_TMP', 2, 1, mx1, mn1)
  htr_b = eis_convert_hk1_htrb_temp(d)
  print, 'HTRB'
  print, d[0:3], format = '(Z02)'  
;  htr_c = eis_convert_hk1_htrc_temp(eis_get_daily_data(files, 'HK1_EIS_C_HTR_TMP', 3, 1, mx2, mn2))
  d = eis_get_daily_data(files, 'HK1_EIS_C_HTR_TMP', 3, 1, mx2, mn2)
  htr_c = eis_convert_hk1_htrc_temp(d)
  print, 'HTRC'
  print, d[0:3], format = '(Z02)'

  avg = (nan_moment(htr_a))[0]
  mn = min(htr_a)
  mx = max(htr_a)
  self->record, 'sur_temps', 'HK1_EIS_A_HTR_TMP', mn, mx, avg
  avg = (nan_moment(htr_b))[0]
  mn = min(htr_b)
  mx = max(htr_b)
  self->record, 'sur_temps', 'HK1_EIS_B_HTR_TMP', mn, mx, avg
  avg = (nan_moment(htr_c))[0]
  mn = min(htr_c)
  mx = max(htr_c)
  self->record, 'sur_temps', 'HK1_EIS_C_HTR_TMP', mn, mx, avg
  
  x = lindgen(n_elements(htr_a)) * 2

;    minr = min([mn0, mn1, mn2])
;    maxr = max([mx0, mx1, mx2])

  cs = 1.6

;    window, /free, xsize=1024
;    !p.multi=0
;    utplot, x, htr_a_array, base_time, timerange=[base_time,end_time],yrange=[minr-1,maxr+1],xstyle=2,pstyle=4,title='Htr A', ytitl='Temp. (Deg C)',charsize=cs
;    outplot,x, htr_b_array,color='0000FF'x
;    outplot,x, htr_c_array,color='00FFFF'x

  set_plot, 'ps'
    ; Could use encapsulated here
;;;    device,xoff=2.5,yoff=6,xs=16,ys=18,file='/tmp/eis_sur_temps.ps'
  device, xoff = 2.5, yoff = 6, xs = 16, ys = 18, file = output + '/eis_sur_temps.ps'
  !p.multi = [0, 1, 3]
  utplot, x, htr_a, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'SUS A MIR', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, htr_b, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'SUS B GRA', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, htr_c, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'SUS C MIR', ytitle = 'Temp. (Deg C)', charsize = cs
  device, /close
  set_plot, 'X'
end

pro eis_status_hk1_data_dumper::plot_str_temps, files, output, end_time
  self->trace, 'eis_status_hk1_data_dumper::plot_str_temps'
  
;  print, '	str_temps'
  
;  str1 = eis_convert_hk1_str1_temp(eis_get_daily_data(files, 'HK1_EIS_STR_1_TEMP',  6, 1, mx0, mn0, base_time, end_time))
  d = eis_get_daily_data(files, 'HK1_EIS_STR_1_TEMP',  6, 1, mx0, mn0, base_time, end_time)
  str1 = eis_convert_hk1_str1_temp(d)
  print, 'STR1'
  print, d[0:3], format = '(Z02)'
;  str2 = eis_convert_hk1_str2_temp(eis_get_daily_data(files, 'HK1_EIS_STR_2_TEMP',  7, 1, mx1, mn1))
  d = eis_get_daily_data(files, 'HK1_EIS_STR_2_TEMP',  7, 1, mx1, mn1, base_time, end_time)
  str2 = eis_convert_hk1_str2_temp(d)
  print, 'STR2'
  print, d[0:3], format = '(Z02)'
;  str3 = eis_convert_hk1_str3_temp(eis_get_daily_data(files, 'HK1_EIS_STR_3_TEMP',  8, 1, mx2, mn2))
  d = eis_get_daily_data(files, 'HK1_EIS_STR_3_TEMP',  8, 1, mx2, mn2, base_time, end_time)
  str3 = eis_convert_hk1_str3_temp(d)
  print, 'STR3'
  print, d[0:3], format = '(Z02)'
;  str4 = eis_convert_hk1_str4_temp(eis_get_daily_data(files, 'HK1_EIS_STR_4_TEMP',  9, 1, mx3, mn3))
  d = eis_get_daily_data(files, 'HK1_EIS_STR_4_TEMP',  9, 1, mx3, mn3, base_time, end_time)
  str4 = eis_convert_hk1_str4_temp(d)
  print, 'STR4'
  print, d[0:3], format = '(Z02)'
  str5 = eis_convert_hk1_str5_temp(eis_get_daily_data(files, 'HK1_EIS_STR_5_TEMP', 10, 1, mx4, mn4))
  str6 = eis_convert_hk1_str6_temp(eis_get_daily_data(files, 'HK1_EIS_STR_6_TEMP', 11, 1, mx5, mn5))
  str7 = eis_convert_hk1_str7_temp(eis_get_daily_data(files, 'HK1_EIS_STR_7_TEMP', 12, 1, mx6, mn6))
  
  avg = (nan_moment(str1))[0]
;    mn = min(str1)
;    mx = max(str1)
  mn = eis_convert_hk1_str1_temp([mn0])
  mx = eis_convert_hk1_str1_temp([mx0])
  self->record, 'str_temps', 'HK1_EIS_STR_1_TEMP', mn, mx, avg
  avg = (nan_moment(str2))[0]
  mn = min(str2)
  mx = max(str2)
  self->record, 'str_temps', 'HK1_EIS_STR_2_TEMP', mn, mx, avg
  avg = (nan_moment(str3))[0]
  mn = min(str3)
  mx = max(str3)
  self->record, 'str_temps', 'HK1_EIS_STR_3_TEMP', mn, mx, avg
  avg = (nan_moment(str4))[0]
  mn = min(str4)
  mx = max(str4)
  self->record, 'str_temps', 'HK1_EIS_STR_4_TEMP', mn, mx, avg
  avg = (nan_moment(str5))[0]
  mn = min(str5)
  mx = max(str5)
  self->record, 'str_temps', 'HK1_EIS_STR_5_TEMP', mn, mx, avg
  avg = (nan_moment(str6))[0]
  mn = min(str6)
  mx = max(str6)
  self->record, 'str_temps', 'HK1_EIS_STR_6_TEMP', mn, mx, avg
  avg = (nan_moment(str7))[0]
  mn = min(str7)
  mx = max(str7)
  self->record, 'str_temps', 'HK1_EIS_STR_7_TEMP', mn, mx, avg
  
  x = lindgen(n_elements(str1)) * 2
  
;    minr = min([mn0, mn1, mn2,mn3,mn4,mn5,mn6])
;    maxr = max([mx0, mx1, mx2,mx3,mx4,mx5,mx6])
  
  cs = 1.6
  
;    window, /free, xsize=1024
;    !p.multi=0
;    utplot, x, htr_a_array, base_time, timerange=[base_time,end_time],yrange=[minr-1,maxr+1],xstyle=2,pstyle=4,title='Htr A', ytitl='Temp. (Deg C)',charsize=cs
;    outplot,x, htr_b_array,color='0000FF'x
;    outplot,x, htr_c_array,color='00FFFF'x
  
  set_plot, 'ps'
                                ; Could use encapsulated here
;;;    device,xoff=2.5,yoff=6,xs=16,ys=18,file='/tmp/eis_str_temps.ps'
  device, xoff = 2.5, yoff = 6, xs= 16, ys = 18, file = output + '/eis_str_temps.ps'
  !p.multi=[0, 1, 3]
  utplot, x, str1, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'Str 1 Outer Door HOPS', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, str2, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'Str 2 Inner Door HOPS', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, str3, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'Str 3 Door Front', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, str4, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'Str 4 Particle Shield', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, str5, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'Str 5 ROE Thermal Shield', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, str6, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'Str 6 ROE Box', ytitle = 'Temp. (Deg C)', charsize = cs
  utplot, x, str7, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
          title = 'Str 7 MHC Ref Foot', ytitle = 'Temp. (Deg C)', charsize = cs
  
  device, /close
  set_plot, 'X'
  
end


pro eis_status_hk1_data_dumper::plot, dir, output, end_time
  self->trace, 'eis_status_hk1_data_dumper::plot'
  
  files = findfile(dir + '/eis_hk1_*fits', count=count)
  if count eq 0 then begin
     print, 'eis_status_hk1_data_dumper::eis_hk1_temperatures : No files'
     return
  endif
  
  self->plot_icu_temps, files, output, end_time
  self->plot_sur_temps, files, output, end_time
  self->plot_str_temps, files, output, end_time
  
  !p.multi = 0
  
  self->debug, self.parameters
  
end
